summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/newformimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/newformimpl.cpp')
-rw-r--r--kdevdesigner/designer/newformimpl.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/kdevdesigner/designer/newformimpl.cpp b/kdevdesigner/designer/newformimpl.cpp
index 80bc6463..6fae9015 100644
--- a/kdevdesigner/designer/newformimpl.cpp
+++ b/kdevdesigner/designer/newformimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -77,20 +77,20 @@ void FormItem::insert( Project *pro )
FormFile *ff = new FormFile( FormFile::createUnnamedFileName(), TRUE, pro );
fw = new FormWindow( ff, MainWindow::self, MainWindow::self->qWorkspace(), n );
fw->setProject( pro );
- MetaDataBase::addEntry( fw );
+ MetaDataBase::addEntry( TQT_TQOBJECT(fw) );
if ( fType == Widget ) {
- TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQWidget" ),
+ TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( TQWIDGET_OBJECT_NAME_STRING ),
fw, n.latin1() );
fw->setMainContainer( w );
} else if ( fType == Dialog ) {
- TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQDialog" ), fw, n.latin1() );
+ TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( TQDIALOG_OBJECT_NAME_STRING ), fw, n.latin1() );
fw->setMainContainer( w );
} else if ( fType == Wizard ) {
- TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQWizard" ),
+ TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( TQWIZARD_OBJECT_NAME_STRING ),
fw, n.latin1() );
fw->setMainContainer( w );
} else if ( fType == MainWindow ) {
- TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQMainWindow" ),
+ TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( TQMAINWINDOW_OBJECT_NAME_STRING ),
fw, n.latin1() );
fw->setMainContainer( w );
}
@@ -109,10 +109,10 @@ void FormItem::insert( Project *pro )
// the wizard might have changed a lot, lets update everything
MainWindow::self->actioneditor()->setFormWindow( fw );
- MainWindow::self->objectHierarchy()->setFormWindow( fw, fw );
+ MainWindow::self->objectHierarchy()->setFormWindow( fw, TQT_TQOBJECT(fw) );
MainWindow::self->objectHierarchy()->formDefinitionView()->refresh();
MainWindow::self->objectHierarchy()->rebuild();
- fw->killAccels( fw );
+ fw->killAccels( TQT_TQOBJECT(fw) );
fw->project()->setModified( TRUE );
fw->setFocus();
if ( !pro->isDummy() ) {
@@ -138,12 +138,12 @@ static void unifyFormName( FormWindow *fw, TQWorkspace *qworkspace )
lst << w->name();
}
- if ( lst.findIndex( fw->name() ) == -1 )
+ if ( lst.tqfindIndex( fw->name() ) == -1 )
return;
TQString origName = fw->name();
TQString n = origName;
int i = 1;
- while ( lst.findIndex( n ) != -1 ) {
+ while ( lst.tqfindIndex( n ) != -1 ) {
n = origName + TQString::number( i++ );
}
fw->setName( n );
@@ -158,13 +158,13 @@ void CustomFormItem::insert( Project *pro )
FormFile *ff = new FormFile( filename, TRUE, pro );
if ( !resource.load( ff ) ) {
TQMessageBox::information( MainWindow::self, i18n("Load Template"),
- i18n("Could not load form description from template '%1'" ).arg( filename ) );
+ i18n("Could not load form description from template '%1'" ).tqarg( filename ) );
delete ff;
return;
}
- ff->setFileName( TQString::null );
+ ff->setFileName( TQString() );
if ( MainWindow::self->formWindow() ) {
- MainWindow::self->formWindow()->setFileName( TQString::null );
+ MainWindow::self->formWindow()->setFileName( TQString() );
unifyFormName( MainWindow::self->formWindow(), MainWindow::self->qWorkspace() );
if ( !pro->isDummy() ) {
MainWindow::self->formWindow()->setSavePixmapInProject( TRUE );
@@ -249,7 +249,7 @@ void NewForm::insertTemplates( TQIconView *tView,
TQStringList languages = MetaDataBase::languages();
if ( !MainWindow::self->singleProjectMode() ) {
for ( it = languages.begin(); it != languages.end(); ++it ) {
- ProjectItem *pi = new ProjectItem( tView, i18n("%1 Project" ).arg( *it ) );
+ ProjectItem *pi = new ProjectItem( tView, i18n("%1 Project" ).tqarg( *it ) );
allItems.append( pi );
pi->setLanguage( *it );
pi->setPixmap( BarIcon( "designer_project.png" , KDevDesignerPartFactory::instance()) );
@@ -282,7 +282,7 @@ void NewForm::insertTemplates( TQIconView *tView,
TQString templPath = templatePath;
TQStringList templRoots;
- const char *qtdir = getenv( "QTDIR" );
+ const char *qtdir = getenv( "TQTDIR" );
if(qtdir)
templRoots << qtdir;
templRoots << qInstallPathData();
@@ -297,16 +297,16 @@ void NewForm::insertTemplates( TQIconView *tView,
}
if ( !templPath.isEmpty() ) {
TQDir dir( templPath );
- const QFileInfoList *filist = dir.entryInfoList( TQDir::DefaultFilter, TQDir::DirsFirst | TQDir::Name );
+ const TQFileInfoList *filist = dir.entryInfoList( TQDir::DefaultFilter, TQDir::DirsFirst | TQDir::Name );
if ( filist ) {
- QFileInfoListIterator it( *filist );
+ TQFileInfoListIterator it( *filist );
TQFileInfo *fi;
while ( ( fi = it.current() ) != 0 ) {
++it;
if ( !fi->isFile() || fi->extension() != "ui" )
continue;
TQString name = fi->baseName();
- name = name.replace( '_', ' ' );
+ name = name.tqreplace( '_', ' ' );
CustomFormItem *ci = new CustomFormItem( tView, name );
allItems.append( ci );
ci->setDragEnabled( FALSE );
@@ -364,9 +364,9 @@ NewForm::NewForm( TQIconView *templateView, const TQString &templatePath )
projectChanged( i18n( "<No Project>" ) );
}
-NewForm::NewForm( TQWidget *parent, const TQStringList& projects,
+NewForm::NewForm( TQWidget *tqparent, const TQStringList& projects,
const TQString& currentProject, const TQString &templatePath )
- : NewFormBase( parent, 0, TRUE )
+ : NewFormBase( tqparent, 0, TRUE )
{
connect( helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
@@ -1,15 +1,15 @@
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the